@@ -21,10 +21,4 @@ class OuterAngle(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=0):
-        XMLScalar.__init__(self, default)
-
-    def _set_value(self, value):
-        assert self._is_scalar(value), \
-            'Input value must be either a float or an integer'
-        assert value >= 0, 'Input value must be greater than zero'
-        XMLScalar._set_value(self, value)
+        super(OuterAngle, self).__init__(default, min_value=0)
